summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSaumit Dinesan <justsaumit@protonmail.com>2022-07-25 22:14:30 +0530
committerSaumit Dinesan <justsaumit@protonmail.com>2022-07-25 22:14:30 +0530
commit752e6f43cbb259edaae4e4e3034c99eaca36dcf2 (patch)
tree54477cb46cdb1b813e28194e29dbf8a021d72899
parent0cc56075bb32083f0af0d312772baaef4265d7fe (diff)
reverting to yay
-rwxr-xr-xarch-magik.sh11
1 files changed, 6 insertions, 5 deletions
diff --git a/arch-magik.sh b/arch-magik.sh
index 27e091f..e024641 100755
--- a/arch-magik.sh
+++ b/arch-magik.sh
@@ -146,18 +146,19 @@ cd ~/.local/src/dwmblocks
sudo make clean install &&
git remote set-url origin git@github.com:justsaumit/dwmblocks.git
# pikaur: AUR helper
cd $HOME
-git clone https://aur.archlinux.org/pikaur.git
-cd pikaur
-makepkg -fsri --noconfirm
+git clone https://aur.archlinux.org/yay.git
+cd yay
+makepkg -si --noconfirm
cd
aurprogs='nerd-fonts-fira-code nerd-fonts-ubuntu-mono adobe-source-code-pro-fonts
picom-git betterlockscreen brave-bin brillo dragon-drop fsearch
gotop-bin bashtop jdownloader2 librewolf-bin quich-git whatsapp-nativefier
spotify ytfzf notepadqq arc-darkest-theme-git galculator gparted'
-sudo pikaur --noconfirm -S $aurprogs && sudo pikaur -S libxft-bgra &&
+yay --noconfirm -S $aurprogs &&
+yay -S libxft-bgra &&
wallp='~/pix/Wallpaper/w/wow'
mkdir -pv $wallp
wget -P $wallp https://images5.alphacoders.com/125/1255724.jpg &
@@ -146,18 +146,19 @@ cd ~/.local/src/dwmblocks
sudo make clean install &&
git remote set-url origin git@github.com:justsaumit/dwmblocks.git
-# pikaur: AUR helper
+# yay: AUR helper
cd $HOME